package com.ruoyi.project.sems.controller;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.file.ExcelUtils;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.project.sems.domain.*;
import com.ruoyi.project.sems.service.ITSpecCheckService;
import com.ruoyi.project.system.domain.SysDept;
import com.ruoyi.project.system.domain.SysDictData;
import com.ruoyi.project.system.service.ISysDeptService;
import com.ruoyi.project.system.service.ISysDictTypeService;
import org.apache.poi.ss.formula.functions.T;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.sems.service.ITSpecdevCcService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 特种设备叉车台账Controller
 *
 * @author ruoyi
 * @date 2021-07-26
 */
@RestController
@RequestMapping("/sems/specCc")
public class TSpecdevCcController extends BaseController
{
    @Autowired
    private ITSpecdevCcService tSpecdevCcService;
    @Autowired
    private ITSpecCheckService tSpecCheckService;
    @Autowired
    private ISysDeptService iSysDeptService;
    @Autowired
    private ISysDictTypeService iSysDictTypeService;
    /**
     * 查询特种设备叉车台账列表
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSpecdevCc tSpecdevCc)
    {
        startPage();
        List<TSpecdevCc> list = tSpecdevCcService.selectTSpecdevCcList(tSpecdevCc);
        return getDataTable(list);
    }

    /**
     * 导出特种设备叉车台账列表
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:export')")
    @Log(title = "特种设备叉车台账", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TSpecdevCc tSpecdevCc)
    {
        List<TSpecdevCc> list = tSpecdevCcService.selectTSpecdevCcList(tSpecdevCc);
        ExcelUtil<TSpecdevCc> util = new ExcelUtil<TSpecdevCc>(TSpecdevCc.class);
        return util.exportExcel(list, "specCc");
    }

    /**
     * 获取特种设备叉车台账详细信息
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tSpecdevCcService.selectTSpecdevCcById(id));
    }

    /**
     * 新增特种设备叉车台账
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:add')")
    @Log(title = "特种设备叉车台账", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSpecdevCc tSpecdevCc)
    {
        return toAjax(tSpecdevCcService.insertTSpecdevCc(tSpecdevCc));
    }

    /**
     * 修改特种设备叉车台账
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:edit')")
    @Log(title = "特种设备叉车台账", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSpecdevCc tSpecdevCc)
    {
        TSpecdevCc old = tSpecdevCcService.selectTSpecdevCcById(tSpecdevCc.getId());
        if (!old.getReportNo().equals(tSpecdevCc.getReportNo())) {
            TSpecCheck tc = new TSpecCheck();
            tc.setDevType(6l);
            tc.setCheckUnit(tSpecdevCc.getCheckUnit());
            tc.setDevId(tSpecdevCc.getId());
            tc.setNextWarnDate(tSpecdevCc.getNextWarnDate());
            tc.setReportNo(tSpecdevCc.getReportNo());
            tc.setWarnDate(tSpecdevCc.getWarnDate());
            tc.setCheckConclusion(tSpecdevCc.getPerTestConclusion());
            tSpecCheckService.insertTSpecCheck(tc);
        }
        return toAjax(tSpecdevCcService.updateTSpecdevCc(tSpecdevCc));
    }

    /**
     * 删除特种设备叉车台账
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:remove')")
    @Log(title = "特种设备叉车台账", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSpecdevCcService.deleteTSpecdevCcByIds(ids));
    }

    /**
     * 去重
     */
    @PreAuthorize("@ss.hasPermi('sems:plant:remove')")
    @Log(title = "特种设备叉车台账去重", businessType = BusinessType.OTHER)
    @GetMapping("/duplicate")
    public AjaxResult duplicate()
    {
        tSpecdevCcService.duplicateTSpecdevCc();
        return AjaxResult.success();
    }

    /**
     * 批量导入
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:add')")
    @Log(title = "特种设备批量导入", businessType = BusinessType.INSERT)
    @PostMapping("/importData")
    public AjaxResult importData(@RequestParam("file") MultipartFile file) throws IOException
    {
        //获取操作人员ID
        Long userId = getUserId();
        //报错行数统计
        List<Integer> failRow =new ArrayList<Integer>();
        Workbook workbook = ExcelUtils.getWorkBook(file);
        Sheet sheet = workbook.getSheetAt(0);
        List<TSpecdevCc> list = new ArrayList<TSpecdevCc>();
        //字典查询
        List<SysDictData> plant = iSysDictTypeService.selectDictDataByType("PLANT_DIVIDE");

        //部门查询
        List<SysDept> dept = iSysDeptService.selectDeptList(new SysDept());
        int rowNum = sheet.getPhysicalNumberOfRows();
        int failNumber = 0;
        for (int i = 1; i < rowNum; i++) {
            try {
                logger.info("读取行数：" + i);
                Row row = sheet.getRow(i);
                int cellNum = row.getLastCellNum();
                TSpecdevCc entity = new TSpecdevCc();
                for (int j = 0; j < cellNum; j++) {
                    Cell cell = row.getCell(j);
                    if (cell == null) {
                        continue;
                    }
                    String cellValue = ExcelUtils.getCellValue(cell);
                    logger.info("cellValue:" + cellValue);
                    if (j == 0) {
                        //序号
                    } else if (j == 1) {
                        entity.setPlantCode(cellValue);//装置名称
                    } else if (j == 2) {
                        entity.setUnit(cellValue);//使用部门
                    }else if (j == 3) {
                        entity.setUseDept(cellValue);//使用部门
                    } else if (j == 4) {
                        entity.setPlantMaint(cellValue);//装置维护组
                    }else if (j == 5) {
                        entity.setEngineer(cellValue);//装置维护人员
                    } else if (j == 6) {
                        entity.setCarNo(cellValue);//车牌号
                    } else if (j == 7) {
                        entity.setDocno(cellValue);//档案号
                    } else if (j == 8) {
                        entity.setEngineNo(cellValue);//发动机号
                    } else if (j == 9) {
                        entity.setRegno(cellValue);//注册代码
                    } else if (j == 10) {
                        entity.setColor(cellValue);//颜色
                    } else if (j == 11) {
                        entity.setCapacity(cellValue);//工作能力
                    } else if (j == 12) {
                        entity.setDevname(cellValue);//设备名称
                    } else if (j == 13) {
                        entity.setEngineType(cellValue);//动力形式
                    } else if (j == 14) {
                        entity.setModel(cellValue);//型号
                    }  else if (j == 15) {
                        entity.setFrameNo(cellValue);//车架号
                    }  else if (j == 16) {
                        entity.setProductNo(cellValue);//产品编号
                    } else if (j == 17) {
                        entity.setCreateUnit(cellValue);//生产厂家
                    } else if (j == 18) {
                        entity.setExUnit(cellValue);//防爆改造厂家
                    } else if (j == 19) {
                        entity.setExGrade(cellValue);//最高防爆级别
                    } else if (j == 20) {
                        if (cellValue.length() > 3) {//初检日期
                            entity.setFirstWarnDate(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));
                        }
                    } else if (j == 21) {
                        entity.setCheckStrategy(cellValue);//检验策略
                    } else if (j == 22) {
                        if (cellValue.length() > 3) {//检验日期
                            entity.setWarnDate(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));
                        }
                    } else if (j == 23) {
                        if (cellValue.length() > 3) {//下次年检日期
                            entity.setNextWarnDate(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));
                        }
                    } else if (j == 24) {
                        entity.setReportNo(cellValue);//报告编号
                    }else if (j == 25) {
                        entity.setAssetOwner(cellValue);//资产形式
                    } else if (j == 26) {
                        entity.setPerTestConclusion(cellValue);
                    }else if (j == 27) {
                        entity.setRemarks(cellValue);//备注
                    }/*else if (j == 25) {
                        for (SysDept d : dept) {
                            if (d.getDeptName().equals(cellValue)) {
                                entity.setDeptId(d.getDeptId());//部门编号
                            }
                        }
                    }*/
                }
                entity.setCreaterCode(userId);
                logger.info("entity:" + entity);
                list.add(entity);
            }catch (Exception e){
                failNumber++;
                logger.info("e:" + JSON.toJSONString(e));
                failRow.add(i + 1);
            }
        }
        int successNumber = 0;
        int failNum = 0;
        for (TSpecdevCc t : list
        ) {
            failNum++;
            try {
                tSpecdevCcService.insertTSpecdevCc(t);
                successNumber++;
            }catch (Exception e){
                failNumber++;
                logger.info("e:" + e);
                failRow.add(failNum + 1);
            }
        }
        logger.info("list:" + JSON.toJSONString(list));
        logger.info("successNumber:" +String.valueOf(successNumber));
        logger.info("failNumber:" +String.valueOf(failNumber));
        logger.info("failRow:" +String.valueOf(failRow));
        return AjaxResult.success(String.valueOf(successNumber), failRow);
    }



    /**
     * 批量导入
     * 检验更新中的批量导入
     */
    @PreAuthorize("@ss.hasPermi('sems:specCc:add')")
    @Log(title = "特种设备批量导入", businessType = BusinessType.INSERT)
    @PostMapping("/updateData")
    public AjaxResult updateData(@RequestParam("file") MultipartFile file)throws IOException{
        //获取操作人员ID
        Long userId = getUserId();
        //报错行数统计
        List<Integer> failRow =new ArrayList<Integer>();
        Workbook workbook = ExcelUtils.getWorkBook(file);
        Sheet sheet = workbook.getSheetAt(0);
        List<TSpecdevCc> list = new ArrayList<TSpecdevCc>();
        List<TSpecdevCc> oldList = new ArrayList<TSpecdevCc>();
        TSpecdevCc oldEntity = new TSpecdevCc();
        //字典查询
        List<SysDictData> plant = iSysDictTypeService.selectDictDataByType("PLANT_DIVIDE");
        //部门查询
        List<SysDept> dept = iSysDeptService.selectDeptList(new SysDept());
        int rowNum = sheet.getPhysicalNumberOfRows();
        int failNumber = 0;
        for (int i = 1; i < rowNum; i++) {
            try {
                logger.info("读取行数：" + i);
                Row row = sheet.getRow(i);
                int cellNum = row.getLastCellNum();
                TSpecdevCc entity = new TSpecdevCc();
                for (int j = 0; j < cellNum; j++) {
                    Cell cell = row.getCell(j);
                    if (cell == null) {
                        continue;
                    }
                    String cellValue = ExcelUtils.getCellValue(cell);
                    logger.info("cellValue:" + cellValue);

                    if (j == 0) {
                        //序号
                        Double d = Double.parseDouble(cellValue);
                        long s = new Double(d).longValue();
                        entity.setId(s);
                    } else if (j == 1) {    //装置名称
                        entity.setPlantCode(cellValue);
                    } else if (j == 2) {
                        entity.setCarNo(cellValue);
                    } else if (j == 3) {
                        entity.setDocno(cellValue);
                    } else if (j == 4) {
                        logger.info("日期格式：" + cellValue);
                        if (cellValue.length() > 3) {
                            entity.setWarnDate(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));
                        }
                    } else if (j == 5) {
                        logger.info("日期格式：" + cellValue);
                        if (cellValue.length() > 3) {
                            entity.setNextWarnDate(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));
                        }
                    } else if (j == 6) {
                        entity.setReportNo(cellValue);
                    }
                    else if (j == 7) {
                        entity.setPerTestConclusion(cellValue);
                    }
                }
                logger.info("entity:" + entity);
                list.add(entity);
                oldEntity = entity;
                oldList.add(oldEntity);
            }catch (Exception e){
                failNumber++;
                logger.info("e:" + JSON.toJSONString(e));
                failRow.add(i + 1);
            }
        }
        int successNumber = 0;
        int failNum = 0;
        for (TSpecdevCc t : list) {
            failNum++;
            try {
                tSpecdevCcService
                        .update(t,
                                new QueryWrapper<TSpecdevCc>()
                                        .eq("DOCNO", t.getDocno())
                                        .eq("CAR_NO", t.getCarNo())
                                        .eq("PLANT_CODE", t.getPlantCode())
                        );
                successNumber++;
            }catch (Exception e){
                failNumber++;
                logger.info("e:" + e);
                failRow.add(failNum + 1);
                e.printStackTrace();
            }
        }
        for (TSpecdevCc t: oldList) {
            TSpecCheck tc = new TSpecCheck();
            tc.setDevType(6l);
            tc.setCheckUnit(t.getCheckUnit());
            tc.setDevId(t.getId());
            tc.setNextWarnDate(t.getNextWarnDate());
            tc.setReportNo(t.getReportNo());
            tc.setWarnDate(t.getWarnDate());
            tc.setCheckConclusion(t.getPerTestConclusion());
            tSpecCheckService.insertTSpecCheck(tc);
        }
        logger.info("list:" + JSON.toJSONString(list));
        logger.info("successNumber:" +String.valueOf(successNumber));
        logger.info("failNumber:" +String.valueOf(failNumber));
        logger.info("failRow:" +String.valueOf(failRow));
        return AjaxResult.success(String.valueOf(successNumber),failRow);
    }


    @GetMapping("/exportDevList")
    public AjaxResult exportbmy(ParamData params) throws IOException {
        logger.info(JSON.toJSONString(params));
        String id = params.getIds();
        String[] ids = id.split(",");
        List<TSpecdevCc> list = new ArrayList<>();
        for (String i : ids
                ) {
                    TSpecdevCc ccEntity = tSpecdevCcService.getById(i);
                    list.add(ccEntity);
                }
        SXSSFWorkbook wb = new SXSSFWorkbook(1000);
        CellStyle wrapStyle = wb.createCellStyle();
        wrapStyle.setWrapText(true);    //设置自动换行
        //创建sheet页
        Sheet sheet = wb.createSheet("sheet1");
        //设置列的宽度，第一个参数为列的序号，从0开始，第二参数为列宽，单位1/256个字节
        sheet.setColumnWidth(0, 12*256);
        sheet.setColumnWidth(1, 26*256);
        sheet.setColumnWidth(2, 26*256);
        sheet.setColumnWidth(3, 26*256);
        sheet.setColumnWidth(4, 26*256);
        sheet.setColumnWidth(5, 26*256);
        sheet.setColumnWidth(6, 26*256);
        sheet.setColumnWidth(7, 26*256);
        sheet.setColumnWidth(8, 40*256);
        //设置开始行和开始列

        Row row0 = sheet.createRow(0);
        CellStyle style = wb.createCellStyle();
        style.setFillForegroundColor(IndexedColors.YELLOW.getIndex());
        style.setFillPattern(FillPatternType.SOLID_FOREGROUND);
//        Font headerFont = wb.createFont();
//        headerFont.setFontName("Arial");
//        headerFont.setFontHeightInPoints((short) 12);
//        headerFont.setBold(false);
//        headerFont.setColor(IndexedColors.BLACK.getIndex());
//        style.setFont(headerFont);
        Cell cell0 = row0.createCell(0);
        row0.createCell(0).setCellValue("序号");
        row0.createCell(1).setCellValue("装置");
        row0.createCell(2).setCellValue("车牌号");
        row0.createCell(3).setCellValue("档案号");
        row0.createCell(4).setCellValue("检验日期");row0.getCell(4).setCellStyle(style);
        row0.createCell(5).setCellValue("下次检验日期");row0.getCell(5).setCellStyle(style);
        row0.createCell(6).setCellValue("报告编号");row0.getCell(6).setCellStyle(style);
        row0.createCell(7).setCellValue("定期检验结论");row0.getCell(7).setCellStyle(style);
        //填充数据
        int rowIndex = 1;
        int columnIndex = 1;
        for (TSpecdevCc t: list
             ) {
            Row row = sheet.createRow(rowIndex);
            row.createCell(0).setCellValue(t.getId());
            row.createCell(1).setCellValue(t.getPlantCode());
            row.createCell(2).setCellValue(t.getCarNo());
            row.createCell(3).setCellValue(t.getDocno());
            if (t.getWarnDate()!= null){
                row.createCell(4).setCellValue(new SimpleDateFormat("yyyy-MM-dd").format(t.getWarnDate()));
            }
            if (t.getNextWarnDate()!= null){
                row.createCell(5).setCellValue(new SimpleDateFormat("yyyy-MM-dd").format(t.getNextWarnDate()));
            }
            row.createCell(6).setCellValue(t.getReportNo());
            row.createCell(7).setCellValue(t.getPerTestConclusion());
            rowIndex++;
        }

        OutputStream out = null;
        String filename = ExcelUtil.encodingFilename("叉车批量更新");
        out = new FileOutputStream(ExcelUtil.getAbsoluteFile(filename));
        wb.write(out);
        wb.close();
        out.close();
        return AjaxResult.success(filename);
    }


}
